# Changelog

## 0.2.1
- Put CHANGES.md into MANIFEST.in
- Fixed major CHANGES.md bug

## 0.2.0
- Added CHANGES.md support
- Changes and refreshed pyproject file
- Fixed minor bugs
- First use of release.sh

## 0.1.9
- Fixed missing color output (Fore.RED not showing in Jupyter)
- Fixed file path for API key loader
- Improved library detection logic

## 0.1.8
- Added cerebras_key.txt support inside package
- Improved packaging with MANIFEST.in

## 0.1.7
- Improved core.chat behavior and fixed minor bugs

## 0.1.6
- Published initial working version of library